package
Version:
v0.1.0
Opens a new window with list of versions in this module.
Published: Jan 28, 2025
License: BSD-2-Clause
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
- Constants
-
func Get(medium Medium, offset, index int) (txnID, pointer, nextOffset, nextIndex int, e error)
-
func Put(medium Medium, offset, txnID int, pointers []int) (head, tail int)
-
type Free
-
type Medium
func Get(medium Medium, offset, index int) (
txnID, pointer, nextOffset, nextIndex int, e error,
)
func Put(medium Medium, offset, txnID int, pointers []int) (head, tail int)
func NewFree(txnID int) (free Free)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.